@@ -5,12 +5,11 @@ from cone.sql.model import SQLRowNodeAttributes
 from cone.sql.model import SQLSession
 from cone.sql.model import UNICODE_TYPE
 from datetime import datetime
-from node.behaviors import Adopt
 from node.behaviors import Attributes
 from node.behaviors import DefaultInit
-from node.behaviors import NodeChildValidate
-from node.behaviors import Nodespaces
-from node.behaviors import Nodify
+from node.behaviors import MappingAdopt
+from node.behaviors import MappingConstraints
+from node.behaviors import MappingNode
 from node.ext.ugm import Group as BaseGroup
 from node.ext.ugm import Groups as BaseGroups
 from node.ext.ugm import Ugm as BaseUgm
@@ -220,7 +219,7 @@ class PrincipalBehavior(Behavior):
     """Reference to sqlalchemy record instance."""
 
     @override
-    def __init__(self, parent, record):
+    def __init__(self, parent=None, record=None):
         self.__parent__ = parent
         self.record = record
 
@@ -311,10 +310,9 @@ class UserBehavior(PrincipalBehavior, BaseUser):
 
 @plumbing(
     UserBehavior,
-    Nodespaces,
     Attributes,
-    Nodify,
-    Adopt,
+    MappingNode,
+    MappingAdopt,
     SQLSession)
 class User(object):
     pass
@@ -365,9 +363,8 @@ class GroupBehavior(PrincipalBehavior, BaseGroup):
 
 @plumbing(
     GroupBehavior,
-    Nodespaces,
     Attributes,
-    Nodify,
+    MappingNode,
     SQLSession)
 class Group(object):
     pass
@@ -585,7 +582,7 @@ class UsersBehavior(PrincipalsBehavior, BaseUsers):
             sqluser = self.session.query(SQLUser).filter(SQLUser.id == id).one()
         except NoResultFound:
             raise KeyError(id)
-        return User(self, sqluser)
+        return User(parent=self, record=sqluser)
 
     @default
     def __delitem__(self, id):
@@ -647,11 +644,10 @@ class UsersBehavior(PrincipalsBehavior, BaseUsers):
 @plumbing(
     UsersBehavior,
     AuthenticationBehavior,
-    NodeChildValidate,
-    Nodespaces,
-    Adopt,
+    MappingConstraints,
+    MappingAdopt,
     Attributes,
-    Nodify,
+    MappingNode,
     SQLSession,
     DefaultInit)
 class Users(object):
@@ -680,7 +676,7 @@ class GroupsBehavior(PrincipalsBehavior, BaseGroups):
                 .one()
         except NoResultFound:
             raise KeyError(id)
-        return Group(self, sqlgroup)
+        return Group(parent=self, record=sqlgroup)
 
     @default
     def __delitem__(self, id):
@@ -710,11 +706,10 @@ class GroupsBehavior(PrincipalsBehavior, BaseGroups):
 
 @plumbing(
     GroupsBehavior,
-    NodeChildValidate,
-    Nodespaces,
-    Adopt,
+    MappingConstraints,
+    MappingAdopt,
     Attributes,
-    Nodify,
+    MappingNode,
     SQLSession,
     DefaultInit)
 class Groups(object):
@@ -734,8 +729,8 @@ class UgmBehavior(BaseUgm):
                  group_attrs, binary_attrs, log_auth):
         self.__name__ = name
         self.__parent__ = parent
-        self.users = Users('users', self)
-        self.groups = Groups('groups', self)
+        self.users = Users(name='users', parent=self)
+        self.groups = Groups(name='groups', parent=self)
         self.user_attrs = user_attrs
         self.group_attrs = group_attrs
         self.binary_attrs = binary_attrs
@@ -779,21 +774,21 @@ class UgmBehavior(BaseUgm):
     @default
     def invalidate(self, key=None):
         if not key:
-            self.users = Users('users', self)
-            self.groups = Groups('groups', self)
+            self.users = Users(name='users', parent=self)
+            self.groups = Groups(name='groups', parent=self)
             return
         if key == 'users':
-            self.users = Users('users', self)
+            self.users = Users(name='users', parent=self)
             return
         if key == 'groups':
-            self.groups = Groups('groups', self)
+            self.groups = Groups(name='groups', parent=self)
             return
         raise KeyError(key)
 
 
 @plumbing(
     UgmBehavior,
-    Nodify,
+    MappingNode,
     SQLSession)
 class Ugm(object):
     pass
